Bastio Agent
============

Bastio is an operating system user account provisioning tool to help
people with a lot of servers and users create and delete system user accounts.
With Bastio, you no longer need to keep track of your team's access to
servers. For example, once a team member leaves, you can disable her access to
all your server assets in one click.

Bastio saves you time by not making you wait for your team members to generate
and send you their public keys; team members can upload their existing
public key. Crypto-savvy members of your team are still free to
generate their own.

Install |project_name| on your servers to enable OS account provisioning and SSH
access management. No daunting configurations needed; all you have to do is specify
your API key and run the agent.

Resources
---------

Extensive documentation is available with the distribution. Refer to the ``doc``
directory after you have generated the Sphinx documentation.

Website: https://bastio.com

Latest Documentation: http://docs.bastio.com

Support Email: support@bastio.com

Git Repository: http://github.com/Databracket/bastio-agent

Copying
-------

Free use of this software is granted under the terms of the GNU General Public
License (GPLv3+). For details see the ``LICENSE`` file included with this
distribution.

